
/**
* Copyright (c) 2016-present, IBM Research
* Licensed under The MIT License [see LICENSE for details]
*/
export = FI;
/**
 * Fragment Identifier (FI.js)
 */
declare class FI {
    /**
     * Create an FI object from an string containing an FI.
     *
     * @param {string} strFI string object containing an FI to be parsed.
     *
     */
    static parseFI(strFI: string): FI;
    /**
     * Create a new FI object.
     *
     * @param {string|FI} artifact string with atomic FIjs or Fijs
     * @param {string|FIAnchor} anchor string or FIAnchor representing anchor
     */
    constructor(artifact: string | FI, anchor?: string | FIAnchor);
    _artifact: any;
    anchor: string | FIAnchor;
    get artifact(): any;
    hasAnchor(): boolean;
    /**
     * Get base artifact of this FI, walking FI.artifact recursively to the base.
     */
    getBaseArtifact(): any;
    /**
     * Returns anchor list to the base artifact, so that an fi = fi.getBaseArtifact() + fi.getAnchorTail().
     *
     * @returns {Array<FIAnchor>}
     */
    getAnchorTail(): Array<FIAnchor>;
    /**
     * Returns the difference of tails between two FIs, For example:
     *
     * art.f1.f2.f3.f4 - art.f1.f2 -> [f3.f4] : Array<FIAnchor>
     * art.f1.f2.f3.f4 - tart.f1.f2 -> [f3.f4] : Array<FIAnchor>
     * art.f1.f2 - art.f1.f2 -> []
     * art.f1.f2 - art.f1.f2.f3 -> []
     * art.f1.f2 - [] -> [f1.f2]
     *
     *
     * @param {FI} fi FI with tail to remove.
     *
     * @return {Array<FIAnchor>} Returns a list with the tails not removed.
     */
    tailDiff(fi: FI): Array<FIAnchor>;
    /**
     * Returns string representation of all anchors from getBaseArtifact()
     */
    toStringTail(): string;
    /**
     * Tests if `fi` is equal to this fi.
     *
     * @param {FI} fi FI to compare.
     */
    equals(fi: FI): boolean;
    toString(): any;
}
import FIAnchor = require("./fianchor");
